Class: OpenTelemetry::Instrumentation::Logger::Instrumentation

Inherits:
Base
  • Object
show all
Defined in:
lib/opentelemetry/instrumentation/logger/instrumentation.rb

Overview

The OpenTelemetry::Instrumentation::Logger::Instrumentation class contains logic to detect and install the Ruby Logger library instrumentation.

Installation and configuration of this instrumentation is done within the OpenTelemetry::SDK#configure block, calling use() or use_all().